Description Usage Format Details References Examples
Options including whether to use a progress bar when knitting a document, and the base directory of images, etc.
1 |
An object of class list of length 5.
Besides the standard usage (opts_knit$set()), we can also set package
options prior to loading knitr or calling knit() using
options() in base R. A global option knitr.package.foo
in options() will be set as an option foo in opts_knit,
i.e. global options in base R with the prefix knitr.package.
correspond to options in opts_knit. This can be useful to set package
options in ‘~/.Rprofile’ without loading knitr.
See str(knitr::opts_knit$get()) for a list of default package options.
Usage: https://yihui.name/knitr/objects/
A list of available options: https://yihui.name/knitr/options/#package_options
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.