Description Usage Arguments Details Value References
The command pdfcrop x x is executed on a PDF plot file, and
convert x -trim x is executed for other types of plot files, where
x is the plot filename.
1 |
x |
Filename of the plot. |
quiet |
Boolean; whether to suppress standard output from the command line utility. |
The utility pdfcrop is often shipped with a LaTeX distribution, and
convert is a command in ImageMagick (Windows users may have to put
the bin path of ImageMagick into the PATH variable).
The original filename.
PDFCrop: https://www.ctan.org/pkg/pdfcrop; the
convert command in ImageMagick:
http://www.imagemagick.org/script/convert.php
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.