Learn R Programming

knitr (version 1.52)

current_input: Query the current input filename

Description

Returns the name of the input file passed to knit().

Usage

current_input(dir = FALSE)

Value

A character string, if this function is called inside an input document. Otherwise NULL.

Arguments

dir

Whether to prepend the current working directory to the file path, i.e., whether to return an absolute path or a relative path.