This function reads the YAML front-matter that has already been extracted from a document and returns a list of any parameters declared there.
knit_params_yaml(yaml, evaluate = TRUE)List of objects of class knit_param that correspond to the
parameters declared in the params section of the YAML. See
knit_params() for a full description of these objects.
Character vector containing the YAML text.
If TRUE (the default), expression values embedded
within the YAML will be evaluated. If FALSE, parameters defined with
an expression will have the parsed but unevaluated expression in their
value field.
knit_params()