path of the template to use (by default
the Rnw template in this package; there is also an HTML
template in knitr)
output
the output filename (passed to
knit); by default it uses the base filename
of the script
Value
path of the output document
Details
The first two lines of the R script can contain the title
and author of the report in comments of the form ##
title: and ## author:. The template must have a
chunk named auto-report, which will be used to
input all the R code from the script. See the examples
below.